WatcherModifiedEvent class

Emitted when a file or directory at path is modified.

Inheritance

Constructors

WatcherModifiedEvent(Path path, bool contentChanged)
Creates a WatcherModifiedEvent for the given path.
const

Properties

contentChanged bool
Whether the file's content changed (true) as opposed to only metadata (e.g. permissions or timestamps) being updated.
final
hashCode int
The hash code for this object.
no setterinherited
path Path
The path of the filesystem entry that triggered this event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited