ServerSocket class abstract
A server socket that listens for incoming TCP connections.
Obtain instances via Network.bind (which returns a resource-managed
server that is automatically closed on release). The accept Rill
emits connected Socket instances, each of which should be closed by
the caller when done (e.g. via Resource or IO.bracket).
Constructors
Properties
-
accept
→ Rill<
Socket> -
A Rill of accepted client connections. Each emitted Socket should be
closed by the caller when done (e.g. via
ResourceorIO.bracket).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
-
localAddress
→ SocketAddress<
Host> -
The local address this server is bound to.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited