WatcherMovedEvent class
Emitted when a file or directory at path is moved or renamed.
- Inheritance
-
- Object
- WatcherEvent
- WatcherMovedEvent
Constructors
-
WatcherMovedEvent(Path path, Option<
Path> destination) -
Creates a WatcherMovedEvent for the given
pathanddestination.const
Properties
-
destination
→ Option<
Path> -
The new location of the entry, or
Noneif the destination could not be determined (e.g. the entry was moved outside the watched tree).final - hashCode → int
-
The hash code for this object.
no setterinherited
- path → Path
-
The path of the filesystem entry that triggered this event.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited